[PyPI](https://pypi.org/project/{{ package_name|replace("_", "-") }}/) | [GitHub](https://github.com/{{ github_package_group|replace("_", "-") }}/{{ github_package_name|replace("_", "-") }}) | [Full documentation](https://{{ package_name|replace("_", "-") }}.readthedocs.io/en/latest/index.html)

Creator & Maintainer: [{{ maintainer.name }}]({{ maintainer.url }})
